California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 054 - LEGISLATURE. LEGISLATION AND PROCEEDINGS. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1386494 | PROTEUS ACTION LEAGUE NON-PROFIT 501 (C)(4) ORGANIZATION, OPPOSING MEASURE 66 AND SUPPORTING MEASURES 54 AND 59 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1381029 | YES ON 54 - VOTERS FIRST, NOT SPECIAL INTERESTS - SPONSORED BY HOLD POLITICIANS ACCOUNTABLE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1389997 | CALIFORNIA COMMON CAUSE -- YES ON 54 AND 59 (NONPROFIT 501(C)(4) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1385928 | CALIFORNIANS FOR AN EFFECTIVE LEGISLATURE | OPPOSE